@@ -38,6 +38,19 @@ def to_docker_camel(string):
             "network_id": "NetworkID",
             "ip_address": "IPAddress",
             "global_ipv6_address": "GlobalIPv6Address",
+            "blkio_device_read_iops": "BlkioDeviceReadIOps",
+            "blkio_device_write_iops": "BlkioDeviceWriteIOps",
+            "device_ids": "DeviceIDs",
+            "kernel_memory_tcp": "KernelMemoryTCP",
+            "container_id_file": "ContainerIDFile",
+            "uts_mode": "UTSMode",
+            "root_fs": "RootFS",
+            "enable_ipv6": "EnableIPv6",
+            "ipv4_address": "IPv4Address",
+            "ipv6_address": "IPv6Address",
+            "ipam": "IPAM",
+            "tls_info": "TLSInfo",
+            "virtual_ips": "VirtualIPs",
         }
         return special_cases[string]
     except KeyError:
